import {Router} from 'react-router-dom';
import createHistory from "history/createBrowserHistory";
import MainPage from "./pages/MainPage";
import Page404 from "./pages/404Page";
import ContactPage from "./pages/ContactPage";
import Switch from "react-router-dom/es/Switch";
import PrivacyPolicy from "./pages/PrivacyPolicyPage";
import FAQPage from "./pages/FAQPage";
import OurTeamPage from "./pages/OurTeamPage";
import AboutUsPage from "./pages/AboutUsPage";
import {Provider} from "react-redux";
import MyAccountPage from "./pages/MyAccountPage";
import {store} from "./reducers";
import ProfilePage from "./pages/ProfilePage";
import CatalogPage from "./pages/CatalogPage";
import Header from "./components/Header";
import {Footer} from "./components/Footer";
import ProductPage from "./pages/ProductPage";
import WishListPage from "./pages/WishListPage";
import SearchPage from "./pages/SearchPage";
import MyOrdersPage from "./pages/MyOrdersPage";
import CartPage from "./pages/CartPage";
import {CPRoute, CRRoute} from "./components/CPRoute";
import AdminPage from "./pages/AdminPage/AdminPage";

const history = createHistory();

export const App = () => {
  return (
      <Router history={history}>
          <Provider store={store}>
              <Header/>
              <Switch>
                  <CRRoute path="/" component={MainPage} exact/>
                  <CRRoute path="/catalog" component={CatalogPage} />
                  <CRRoute path="/good" component={ProductPage} />
                  <CRRoute path="/about-us" component={AboutUsPage} />
                  <CRRoute path="/our-team" component={OurTeamPage} />
                  <CRRoute path="/faq" component={FAQPage} />
                  <CRRoute path="/contact" component={ContactPage} />
                  <CRRoute path="/my-account" component={MyAccountPage} />
                  <CRRoute path="/privacy-policy" component={PrivacyPolicy} />
                  <CRRoute path="/search" component={SearchPage} />
                  <CRRoute path="/basket" component={CartPage} />
                  <CRRoute path="/wish-list" component={WishListPage} />
                  <CRRoute path="/my-orders" component={MyOrdersPage} />
                  <CPRoute roles={["user", "admin"]} path="/profile" fallback='/my-account' component={ProfilePage} />
                  <CPRoute roles={["admin"]} path="/admin" fallback='/my-account' component={AdminPage} />
                  <CRRoute path="*" component={Page404} />
              </Switch>
              <Footer/>
          </Provider>
      </Router>
  )
}
